eigenvalues_3x3_symmetric

Function eigenvalues_3x3_symmetric 

fn eigenvalues_3x3_symmetric(
    a: f64,
    b: f64,
    c: f64,
    d: f64,
    e: f64,
    f: f64,
) -> (f64, f64, f64)
Compute eigenvalues of a 3x3 symmetric matrix using Householder + QL algorithm

This is a direct port of the QSMART/JAMA algorithm from eig3volume.c, which uses Householder reduction to tridiagonal form followed by QL iteration. This method is more numerically stable than the analytical Cardano formula.

Matrix is: | a d e | | d b f | | e f c |

Returns eigenvalues (not sorted)